@@ -31,20 +31,11 @@
 #' @export
 #' @seealso \link{propSymbolsLayer}
 #' @examples
-#' # Example 1
-#' library(sp)
-#' data("nuts2006")
-#' plot(nuts0.spdf)
-#' dotDensityLayer(spdf = nuts0.spdf, df=nuts0.df,var="pop2008")
-#' 
-#' # Example 2
 #' library(sf)
-#' mtq <- st_read(system.file("shape/martinique.shp", package="cartography"))
-#' plot(st_geometry(mtq), col = "#B8704D50",border = "white")
-#' dotDensityLayer(x = mtq,  var="P13_POP", pch=20, col = "brown", n = 50)
-#' layoutLayer(title = "Population in Martinique, 2013", 
-#'             sources = "INSEE, 2016", scale = NULL, frame = FALSE,
-#'             theme = "brown.pal")
+#' mtq <- st_read(system.file("gpkg/mtq.gpkg", package="cartography"))
+#' plot(st_geometry(mtq), col = "#B8704D50")
+#' dotDensityLayer(x = mtq,  var="POP", pch=20, col = "red4", n = 50)
+#' layoutLayer(title = "Population Distribution in Martinique, 2015")
 dotDensityLayer <- function(x, spdf, df, spdfid = NULL, dfid = NULL, var,
                             n = NULL, # Un point vaut nb units
                             iter = 5,
@@ -72,7 +63,7 @@ dotDensityLayer <- function(x, spdf, df, spdfid = NULL, dfid = NULL, var,
   }
   
   spdf@data[is.na(spdf@data$var),"var"] <- 0
-  if (is.null(n)){n <- round(sum(spdf@data$var)/5000,-3)}
+  if (is.null(n)){n <- round(min(spdf@data$var),0)+1}
   spdf@data$ndots <- as.integer(spdf@data$var/n)
   spdf <- spdf[spdf@data$ndots>0,]
   
