@@ -14,17 +14,16 @@
 #' @param dfide defunct.
 #' @return An sf LINESTRING is returned, it contains two fields (origins and destinations).
 #' @examples 
-#' library(sp)
 #' library(sf)
-#' data("nuts2006")
+#' mtq <- st_read(system.file("gpkg/mtq.gpkg", package="cartography"))
+#' mob <- read.csv(system.file("csv/mob.csv", package="cartography"))
+#' # Select links from Fort-de-France (97209))
+#' mob_97209 <- mob[mob$i == 97209, ]
 #' # Create a link layer
-#' head(twincities.df)
-#' # Select links from Ireland (IE)
-#' twincitiesIE <- twincities.df[substr(twincities.df$i,1,2)=="IE", ]
-#' twincities.sf <- getLinkLayer(x = nuts2.spdf, df = twincitiesIE, dfid = c("i", "j"))
-#' # Plot the links
-#' plot(nuts2.spdf, col = "#6C6870")
-#' plot(st_geometry(twincities.sf), col = "#F78194", add = TRUE)
+#' mob.sf <- getLinkLayer(x = mtq, df = mob_97209, dfid = c("i", "j"))
+#' # Plot the links1
+#' plot(st_geometry(mtq), col = "grey")
+#' plot(st_geometry(mob.sf), col = "red4", lwd = 2, add = TRUE)
 #' @seealso \link{gradLinkLayer}, \link{propLinkLayer}
 #' @export
 getLinkLayer <- function(x, xid = NULL, df, dfid = NULL, spdf, spdf2 = NULL, 
@@ -41,13 +40,26 @@ if(sum(missing(spdf), is.null(spdf2), is.null(spdfid),
   if (is.null(dfid)){dfid <- names(df)[1:2]}
   x2 <- data.frame(id = x[[xid]], 
                    sf::st_coordinates(sf::st_centroid(x = sf::st_geometry(x), of_largest_polygon = max(sf::st_is(sf::st_as_sf(x), "MULTIPOLYGON")))), 
-                   stringsAsFactors = F)
+                   stringsAsFactors = FALSE)
   # names(x2)[2:3] <- c('X', 'Y')
   df <- df[,dfid]
   link <- merge(df, x2, by.x = dfid[2], by.y = "id", all.x = TRUE)
   link <- merge(link, x2, by.x =  dfid[1], by.y = "id", all.x = TRUE)
   names(link)[3:6] <- c('xj', 'yj', 'xi', 'yi')
 
+  # watch for NAs
+  d1 <- nrow(link)
+  link <- link[!is.na(link$xj) & !is.na(link$xi),]
+  d2 <- nrow(link)
+  if(d2 == 0){
+    stop("No links were created. dfid and xid do not match", call. = FALSE)
+  }
+  if((d1 - d2) > 0){
+    warning(paste0((d1 - d2), 
+                   " links were not created. Some dfid were not found in xid"), 
+            call. = FALSE)
+  }
+  
   stringo <- paste0('LINESTRING(', link$xi, " ",link$yi, ", ", 
                     link$xj, " ", link$yj, ")")
   link <- sf::st_sf(link[, dfid], 
